@@ -24,15 +24,15 @@ class ParleyMainWindow;
 class QTimer;
 
 /**
-	@author Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    @author Frederik Gladhorn <frederik.gladhorn@kdemail.net>
 */
 class ParleyDocument : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 public:
     ParleyDocument(ParleyMainWindow* parleyMainWindow);
     ~ParleyDocument();
-    
+
 
     KEduVocDocument *document();
 
@@ -63,6 +63,8 @@ public slots:
 
     /** merge a document */
     void slotFileMerge();
+    /** save a document if it has changed. Used for automatic saving of backup files.  */
+    void autoSave();
     /** save a document */
     void save();
     void saveAs(KUrl file = KUrl());
@@ -70,11 +72,11 @@ public slots:
     void exportDialog();
 
     void newDocument(bool wizard);
-    
+
     /** General doc properties like title, author etc */
     void documentProperties();
     void languageProperties();
-    
+
 signals:
     void documentChanged(KEduVocDocument *newDocument);
     void languagesChanged();
