@@ -15,17 +15,21 @@
 
 #include "ui_practice_widget_flashcard.h"
 
+#include <KUrl>
+
 #include "guifrontend.h"
 #include "latexrenderer.h"
 
 using namespace Practice;
 
 
-FlashCardModeWidget::FlashCardModeWidget (GuiFrontend *frontend, QWidget* parent )
-    : AbstractModeWidget (frontend, parent), m_questionLatexRenderer(0), m_solutionLatexRenderer(0)
+FlashCardModeWidget::FlashCardModeWidget(GuiFrontend *frontend, QWidget* parent)
+    : AbstractModeWidget(frontend, parent), m_questionLatexRenderer(0), m_solutionLatexRenderer(0)
 {
     m_ui = new Ui::FlashCardPracticeWidget();
     m_ui->setupUi(this);
+    connect(frontend, SIGNAL(continueAction()), this, SIGNAL(stopAudio()));
+    connect(frontend, SIGNAL(skipAction()), this, SIGNAL(stopAudio()));
 }
 
 void FlashCardModeWidget::setQuestionFont(const QFont& font)
@@ -42,12 +46,24 @@ void FlashCardModeWidget::setQuestion(const QVariant& question)
 {
     m_ui->questionLabel->setMinimumSize(QSize(0, 0));
     if (LatexRenderer::isLatex(question.toString())) {
-        if(!m_questionLatexRenderer) {
+        if (!m_questionLatexRenderer) {
             m_questionLatexRenderer = new LatexRenderer(this);
             m_questionLatexRenderer->setResultLabel(m_ui->questionLabel);
         }
         m_questionLatexRenderer->renderLatex(question.toString());
+    } else if (question.canConvert<KUrl>()) {
+        // A KUrl means an image.
+        QPixmap pixmap(question.value<KUrl>().path());
+        if (pixmap.isNull()) {
+            // Couldn't create the pixmap from the path.  This should not happen!
+            // FIXME: Do something here (the line below is stolen from guifrontend.cpp
+            //m_ui->questionLabel->setPixmap(m_themedBackgroundRenderer->getPixmapForId("image-placeholder", QSize(150, 150)));
+        } else {
+            m_ui->questionLabel->setPixmap(pixmap.scaled(m_ui->questionLabel->size(),
+                                                         Qt::KeepAspectRatio ));
+        }
     } else {
+        // A normal text.
         m_ui->questionLabel->setText(question.toString());
     }
 }
@@ -56,6 +72,11 @@ void FlashCardModeWidget::showQuestion()
 {
     m_ui->solutionLabel->setHidden(true);
     m_frontend->showSetResultButtons(false);
+
+    m_ui->questionPronunciationLabel->setVisible(m_ui->questionPronunciationLabel->isEnabled());
+    m_ui->questionSoundButton->setVisible(true); // TODO: Use Configuration's Sound Enable QCheckbox
+    m_ui->solutionPronunciationLabel->setVisible(false);
+    m_ui->solutionSoundButton->setVisible(false);
 }
 
 void FlashCardModeWidget::setSolution(const QVariant& solution)
@@ -63,23 +84,24 @@ void FlashCardModeWidget::setSolution(const QVariant& solution)
     m_solution = solution.toString();
 }
 
-void FlashCardModeWidget::setSynonym(const QString& entry)
+void FlashCardModeWidget::setSynonym(const QString& /*entry*/)
 {
-  //TODO Do something here to show synonyms
+    //TODO Do something here to show synonyms
 }
 
 void FlashCardModeWidget::showSynonym()
 {
-  //TODO Do something here to show synonyms
+    //TODO Do something here to show synonyms
 }
 
 void FlashCardModeWidget::showSolution()
 {
+    m_ui->solutionLabel->setHidden(true);
     m_ui->solutionLabel->setPalette(m_correctPalette);
 
     m_ui->solutionLabel->setMinimumSize(QSize(0, 0));
     if (LatexRenderer::isLatex(m_solution)) {
-        if(!m_solutionLatexRenderer) {
+        if (!m_solutionLatexRenderer) {
             m_solutionLatexRenderer = new LatexRenderer(this);
             m_solutionLatexRenderer->setResultLabel(m_ui->solutionLabel);
         }
@@ -90,12 +112,16 @@ void FlashCardModeWidget::showSolution()
 
     m_ui->solutionLabel->setHidden(false);
     m_frontend->showSetResultButtons(true);
+
+    m_ui->solutionPronunciationLabel->setVisible(m_ui->solutionPronunciationLabel->isEnabled());
+    m_ui->solutionSoundButton->setVisible(true); // TODO: Use Configuration's Sound Enable QCheckbox
 }
 
 void FlashCardModeWidget::setHint(const QVariant& hint)
 {
-    m_ui->solutionLabel->setHidden(false);
+    m_ui->solutionLabel->setHidden(true);
     m_ui->solutionLabel->setText(hint.toString());
+    m_ui->solutionLabel->setHidden(false);
 }
 
 QVariant FlashCardModeWidget::userInput()
@@ -105,22 +131,24 @@ QVariant FlashCardModeWidget::userInput()
 
 void FlashCardModeWidget::setQuestionSound(const KUrl& soundUrl)
 {
-
+    m_ui->questionSoundButton->setSoundFile(soundUrl);
 }
 
 void FlashCardModeWidget::setSolutionSound(const KUrl& soundUrl)
 {
-
+    m_ui->solutionSoundButton->setSoundFile(soundUrl);
 }
 
 void FlashCardModeWidget::setSolutionPronunciation(const QString& pronunciationText)
 {
-
+    m_ui->solutionPronunciationLabel->setText('[' + pronunciationText + ']');
+    m_ui->solutionPronunciationLabel->setEnabled(!pronunciationText.isNull());
 }
 
 void FlashCardModeWidget::setQuestionPronunciation(const QString& pronunciationText)
 {
-
+    m_ui->questionPronunciationLabel->setText('[' + pronunciationText + ']');
+    m_ui->questionPronunciationLabel->setEnabled(!pronunciationText.isNull());
 }
 
 #include "flashcardmodewidget.moc"
