@@ -32,9 +32,12 @@ public:
 
 private Q_SLOTS:
     void removeGrades();
+    void removeGradesChildren();
 
 private:
-    virtual void setModel(QAbstractItemModel *model) { Q_UNUSED(model) }
+    virtual void setModel(QAbstractItemModel *model) {
+        Q_UNUSED(model)
+    }
 };
 
 #endif
